CREATE TABLE `doctype` (
  `doctype_id` int NOT NULL AUTO_INCREMENT,
  `doctype_name` varchar(50) NOT NULL default '' COLLATE utf8_bin,
  `doctype_func` varchar(30) NOT NULL default '' COLLATE utf8_bin,
  PRIMARY KEY  (`doctype_id`)
) CHARACTER SET=utf8; 

ALTER TABLE `doctype` ADD UNIQUE (
`doctype_name` 
); 

CREATE TABLE `doc` (
  `doc_id` int NOT NULL AUTO_INCREMENT,
  `doctype_id` int NOT NULL,
  `creater_id` int NOT NULL,
  `control_id` int NOT NULL,
  `doc_date` timestamp NOT NULL default CURRENT_TIMESTAMP,
  `doc_name` varchar(50) NOT NULL default '' COLLATE utf8_bin,
  `doc_active` int NOT NULL,
  PRIMARY KEY  (`doc_id`), 
  KEY `doctype_id` (`doctype_id`),
  KEY `creater_id` (`creater_id`),
  KEY `control_id` (`control_id`),
  INDEX ( `doc_date` )
) CHARACTER SET=utf8;


CREATE TABLE `docatrtypetype` (
  `docatrtypetype_id` int NOT NULL AUTO_INCREMENT,
  `docatrtypetype_name` varchar(50) NOT NULL COLLATE utf8_bin,
  PRIMARY KEY  (`docatrtypetype_id`)
) CHARACTER SET=utf8; 

insert into docatrtypetype(docatrtypetype_id, docatrtypetype_name)
values(1, 'Float');
insert into docatrtypetype(docatrtypetype_id, docatrtypetype_name)
values(2, 'Int');
insert into docatrtypetype(docatrtypetype_id, docatrtypetype_name)
values(3, 'Date');
insert into docatrtypetype(docatrtypetype_id, docatrtypetype_name)
values(4, 'String line');
insert into docatrtypetype(docatrtypetype_id, docatrtypetype_name)
values(5, 'String area');


CREATE TABLE `docatrtypegroup` (
  `docatrtypegroup_id` int NOT NULL AUTO_INCREMENT,
  `docatrtypegroup_name` varchar(50) NOT NULL COLLATE utf8_bin,
  PRIMARY KEY  (`docatrtypegroup_id`)
) CHARACTER SET=utf8; 

ALTER TABLE `docatrtypegroup` ADD UNIQUE (
`docatrtypegroup_name` 
); 

CREATE TABLE `docatrtypegroupdoctype` (
  `docatrtypegroupdoctype_id` int NOT NULL AUTO_INCREMENT,
  `doctype_id` int NOT NULL,
  `docatrtypegroup_id` int NOT NULL,
  PRIMARY KEY  (`docatrtypegroupdoctype_id`), 
  KEY `doctype_id` (`doctype_id`),
  KEY `docatrtypegroup_id` (`docatrtypegroup_id`)
) CHARACTER SET=utf8; 

ALTER TABLE `docatrtypegroupdoctype` ADD UNIQUE (
`doctype_id` ,
`docatrtypegroup_id`
);

CREATE TABLE `docatrtype` (
  `docatrtype_id` int NOT NULL AUTO_INCREMENT,
  `docatrtypegroup_id` int NOT NULL,
  `docatrtypetype_id` int NOT NULL,
  `docatrtype_name` varchar(50) NOT NULL COLLATE utf8_bin,
  `docatrtype_func` varchar(30) NOT NULL COLLATE utf8_bin,
  PRIMARY KEY  (`docatrtype_id`),
  KEY `docatrtypegroup_id` (`docatrtypegroup_id`),
  KEY `docatrtypetype_id` (`docatrtypetype_id`)
) CHARACTER SET=utf8; 

CREATE TABLE `docatr` (
  `docatr_id` int NOT NULL AUTO_INCREMENT,
  `doc_id` int NOT NULL,
  `docatrtype_id` int NOT NULL,
  `docatr_float` double precision default null,
  `docatr_int` int default null,
  `docatr_date` timestamp,
  `docatr_varchar` varchar(50) default null COLLATE utf8_bin,
  `docatr_blob` text default null COLLATE utf8_bin,
  PRIMARY KEY  (`docatr_id`),
  KEY `doc_id` (`doc_id`),
  KEY `docatrtype_id` (`docatrtype_id`)
) CHARACTER SET=utf8; 

CREATE TABLE `usergroup` (
  `usergroup_id` int NOT NULL AUTO_INCREMENT,
  `parent_id` int NOT NULL,  
  `usergroup_name` varchar(50) NOT NULL COLLATE utf8_bin,
  PRIMARY KEY  (`usergroup_id`),
  KEY `parent_id` (`parent_id`)
) CHARACTER SET=utf8; 

insert into usergroup(usergroup_id, parent_id, usergroup_name) 
values(1, 1, 'root');

CREATE TABLE `proguser` (
  `proguser_id` int NOT NULL AUTO_INCREMENT,
  `usergroup_id` int NOT NULL,  
  `proguser_name` varchar(50) NOT NULL COLLATE utf8_bin,
  `proguser_surname` varchar(50) NOT NULL COLLATE utf8_bin,
  `proguser_middlename` varchar(50) NOT NULL COLLATE utf8_bin,
  `proguser_login` varchar(30) NOT NULL COLLATE utf8_bin,  
  `proguser_password` varchar(30) NOT NULL COLLATE utf8_bin,
  `proguser_func` varchar(30) NOT NULL COLLATE utf8_bin,
  PRIMARY KEY  (`proguser_id`),
  KEY `usergroup_id` (`usergroup_id`), 
  UNIQUE(`proguser_login`)
) CHARACTER SET=utf8; 

insert into proguser(proguser_id, usergroup_id, proguser_name, proguser_surname, proguser_middlename, proguser_login, proguser_password, proguser_func)
values(1, 1, 'root', 'root', 'root', 'root', '1', 'a');

CREATE TABLE `docuser` (
  `docuser_id` int NOT NULL AUTO_INCREMENT,
  `doc_id` int NOT NULL,  
  `proguser_id` int NOT NULL,  
  `docuser_state` int NOT NULL,
  PRIMARY KEY  (`docuser_id`),
  KEY `doc_id` (`doc_id`),
  KEY `proguser_id` (`proguser_id`)
) CHARACTER SET=utf8;

CREATE TABLE `docuserlog` (
  `docuserlog_id` int NOT NULL AUTO_INCREMENT,  
  `docuser_id` int NOT NULL,  
  `proguser_id` int NOT NULL,  
  `docuserlog_state` int NOT NULL,
  `docuserlog_date` timestamp NOT NULL,
  `docuserlog_text` text COLLATE utf8_bin,
  PRIMARY KEY  (`docuserlog_id`),
  KEY `docuser_id` (`docuser_id`),
  KEY `proguser_id` (`proguser_id`)
) CHARACTER SET=utf8;

CREATE TABLE `docfile` (
  `docfile_id` int NOT NULL AUTO_INCREMENT,  
  `doc_id` int NOT NULL,  
  `proguser_id` int NOT NULL,  
  `docfile_name` varchar(50) NOT NULL COLLATE utf8_bin,
  `docfile_text` text COLLATE utf8_bin,
  `docfile_date` timestamp NOT NULL,  
  `docfile_size` int NOT NULL,  
  PRIMARY KEY  (`docfile_id`),
  KEY `doc_id` (`doc_id`),
  KEY `proguser_id` (`proguser_id`)
) CHARACTER SET=utf8;

CREATE TABLE `doclinktype` (
  `doclinktype_id` int NOT NULL AUTO_INCREMENT,  
  `doclinktype_name` varchar(50) NOT NULL COLLATE utf8_bin,  
  PRIMARY KEY  (`doclinktype_id`)
) CHARACTER SET=utf8;

insert into doclinktype(doclinktype_id, doclinktype_name) 
values(1, 'Slave document');

CREATE TABLE `doclink` (
  `doclink_id` int NOT NULL AUTO_INCREMENT,  
  `master_id` int NOT NULL,
  `slave_id` int NOT NULL,
  `doclinktype_id` int NOT NULL,
  PRIMARY KEY  (`doclink_id`),
  KEY `master_id` (`master_id`),
  KEY `slave_id` (`slave_id`)
) CHARACTER SET=utf8;

CREATE TABLE `chat` (
  `chat_id` int NOT NULL AUTO_INCREMENT,  
  `doc_id` int NOT NULL,  
  `chat_name` varchar(50) NOT NULL COLLATE utf8_bin,
  PRIMARY KEY  (`chat_id`),
  KEY `doc_id` (`doc_id`)
) CHARACTER SET=utf8;

CREATE TABLE `chatuser` (
  `chatuser_id` int NOT NULL AUTO_INCREMENT,  
  `chat_id` int NOT NULL,  
  `proguser_id` int NOT NULL,
  `chatuser_func` varchar(30) COLLATE utf8_bin,
  PRIMARY KEY  (`chatuser_id`),
  KEY `chat_id` (`chat_id`),
  KEY `proguser_id` (`proguser_id`)
) CHARACTER SET=utf8;

CREATE TABLE `chatmessage` (
  `chatmessage_id` int NOT NULL AUTO_INCREMENT,  
  `chatuser_id` int NOT NULL,    
  `chatmessage_date` timestamp not null,
  `chatmessage_text` text not null COLLATE utf8_bin,  
  PRIMARY KEY  (`chatmessage_id`),
  KEY `chatuser_id` (`chatuser_id`)
) CHARACTER SET=utf8;

CREATE TABLE `docsee` (  
  `doc_id` int NOT NULL,
  `proguser_id` int NOT NULL,  
  `docsee_date` timestamp not null,
  KEY `doc_id` (`doc_id`),
  KEY `proguser_id` (`proguser_id`),
  UNIQUE(`doc_id`, `proguser_id`)
) CHARACTER SET=utf8;

/* 1.5 */
CREATE TABLE `news` (  
  `news_id` int NOT NULL AUTO_INCREMENT,
  `proguser_id` int NOT NULL,  
  `newstype_id` int NOT NULL,  
  `news_date` timestamp not null,
  `record1_id` int,  
  `record2_id` int,  
  `news_text` text COLLATE utf8_bin,
  KEY `news_id` (`news_id`),
  KEY `proguser_id` (`proguser_id`)  
) CHARACTER SET=utf8;

ALTER TABLE `proguser` ADD `proguser_email` VARCHAR(50) COLLATE utf8_bin;

CREATE TABLE `progusercookies` (  
  `progusercookies_id` int NOT NULL AUTO_INCREMENT,
  `proguser_id` int NOT NULL,    
  `progusercookies_code` varchar(100) not null COLLATE utf8_bin,  
  KEY `progusercookies_id` (`progusercookies_id`),  
  KEY `proguser_id` (`proguser_id`), 
  UNIQUE(`progusercookies_code`)  
) CHARACTER SET=utf8;

CREATE TABLE `docuserlistgroup` (  
  `docuserlistgroup_id` int NOT NULL AUTO_INCREMENT,
  `docuserlistgroup_name` varchar(50) not null COLLATE utf8_bin,  
  KEY `docuserlistgroup_id` (`docuserlistgroup_id`),    
  UNIQUE(`docuserlistgroup_name`)  
) CHARACTER SET=utf8;

CREATE TABLE `docuserlist` (  
  `docuserlist_id` int NOT NULL AUTO_INCREMENT,
  `docuserlistgroup_id` int NOT NULL, 
  `proguser_id` int NOT NULL,    
  KEY `docuserlist_id` (`docuserlist_id`),  
  KEY `docuserlistgroup_id` (`docuserlistgroup_id`),   
  KEY `proguser_id` (`proguser_id`)
) CHARACTER SET=utf8;

CREATE TABLE `lastcontrol` (  
  `lastcontrol_id` int NOT NULL AUTO_INCREMENT,  
  `proguser_id` int NOT NULL,    
  `control_id` int NOT NULL, 
  KEY `lastcontrol_id` (`lastcontrol_id`),  
  KEY `proguser_id` (`proguser_id`),   
  KEY `control_id` (`control_id`)
) CHARACTER SET=utf8;

CREATE TABLE `keys` (  
  `keys_id` int NOT NULL AUTO_INCREMENT,  
  `keys_text` varchar(250) not null COLLATE utf8_bin,  
  `keys_date` timestamp not null,
  KEY `keys_id` (`keys_id`), 
  UNIQUE(`keys_text`)
) CHARACTER SET=utf8;

insert into `keys`(keys_text) 
values('Y1AQM-HE3LN-FB5HB-SWB6Q');

CREATE TABLE `interfacestyle` (  
  `interfacestyle_id` int NOT NULL AUTO_INCREMENT,  
  `interfacestyle_type` int not null,  
  `proguser_id` int NOT NULL,    
  KEY `interfacestyle_id` (`interfacestyle_id`), 
  UNIQUE(`proguser_id`)   
) CHARACTER SET=utf8;








